Keyboard shortcuts

Press ← or → to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

Home Manager module options

Generated from homeManagerModules.default when this site was built.

programs.nix-skills.enable

Whether to enable the selected portable Nix skills.

Type: boolean

Default:

false

Example:

true

Declared by:

programs.nix-skills.agents

Agents to install into their native user skill directories.

Type: list of (one of “antigravity”, “claude”, “codex”, “opencode”)

Default:

[ ]

Declared by:

programs.nix-skills.directory

Destination relative to the home directory, without dot or parent components.

Type: string

Default:

".agents/skills"

Declared by:

programs.nix-skills.skills

Skill directories to link; defaults to the complete collection.

Type: list of (one of “devenv-project”, “home-manager”, “microvm-nix”, “nix-darwin”, “nix-language”, “nix-workflow”, “nixos-coding-agents”, “nixos-operations”, “nixos-wiki”, “nixpkgs-development”)

Default:

[
  "devenv-project"
  "home-manager"
  "microvm-nix"
  "nix-darwin"
  "nix-language"
  "nix-workflow"
  "nixos-coding-agents"
  "nixos-operations"
  "nixos-wiki"
  "nixpkgs-development"
]

Declared by: